AnalyticsPlatformImpl class

A web implementation of the AnalyticsPlatform of the Analytics plugin.

Inheritance

Constructors

AnalyticsPlatformImpl()
Constructs a AnalyticsWeb

Properties

hashCode → int
The hash code for this object.
no setterinherited
linkStream → Stream<Map<String, dynamic>>
A broadcast stream for receiving incoming link change events.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getContext({bool collectDeviceId = false}) → Future<NativeContext>
Returns a String containing the version of the platform.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited