LogMessage class

The interface to the message being returned to LogTarget -> parseLog().

Constructors

LogMessage(LogFilterKind kind, String message, LogDestination logType)

Properties

hashCode → int
The hash code for this object.
no setterinherited
kind → LogFilterKind
final
logType → LogDestination
final
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited