EventLogger class

Inheritance

Constructors

EventLogger()

Properties

analytics → Analytics?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
key → String
finalinherited
logKind ↔ LogFilterKind
getter/setter pair
pAnalytics ↔ Analytics?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeline ↔ Timeline
getter/setter pairinherited
type → PluginType
finalinherited

Methods

add(Plugin plugin) → Plugin
Adds a new plugin to the currently loaded set.
inherited
alias(AliasEvent event) → Future<RawEvent?>
inherited
apply(PluginClosure closure) → void
Applies the supplied closure to the currently loaded set of plugins.
inherited
clear() → void
inherited
configure(Analytics analytics) → void
override
execute(RawEvent event) → Future<RawEvent?>
override
flush() → Future
inherited
group(GroupEvent event) → Future<RawEvent?>
inherited
identify(IdentifyEvent event) → Future<RawEvent?>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
process(RawEvent event) → Future<RawEvent?>
inherited
remove(Plugin plugin) → void
Removes and unloads plugins with a matching name from the system. Parameter pluginName: An plugin name.
inherited
reset() → FutureOr<void>
inherited
screen(ScreenEvent event) → Future<RawEvent?>
inherited
shutdown() → void
inherited
toString() → String
A string representation of this object.
inherited
track(TrackEvent event) → Future<RawEvent?>
inherited
update(Map<String, dynamic> settings, ContextUpdateType type) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited