QueueFlushingPlugin class

Inheritance

Constructors

QueueFlushingPlugin(OnFlush _onFlush)
@param onFlush callback to execute when the queue is flushed (either by reaching the limit or manually) e.g. code to upload events to your destination

Properties

analytics → Analytics?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
pAnalytics ↔ Analytics?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → PluginType
finalinherited

Methods

alias(AliasEvent event) → Future<RawEvent?>
inherited
clear() → void
inherited
configure(Analytics analytics) → void
override
dequeue(List<RawEvent> eventsToRemove) → Future
Removes one or multiple events from the queue @param events events to remove
execute(RawEvent event) → Future<RawEvent>
override
flush() → Future
Calls the onFlush callback with the events in the queue
override
group(GroupEvent event) → Future<RawEvent?>
inherited
identify(IdentifyEvent event) → Future<RawEvent?>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → FutureOr<void>
inherited
screen(ScreenEvent event) → Future<RawEvent?>
inherited
shutdown() → void
inherited
toString() → String
A string representation of this object.
inherited
track(TrackEvent event) → Future<RawEvent?>
inherited
update(Map<String, dynamic> settings, ContextUpdateType type) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited