EnrichedSessionEvent class

Constructors

EnrichedSessionEvent({required ContextSession contextSession, required SessionState sessionState})

Properties

contextSession ContextSession
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionState SessionState
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited