validateSessionTimeouts static method
Implementation
static void validateSessionTimeouts(Configuration config) {
if (config.foregroundSessionTimeout < 0) {
throw ArgumentError(
'foregroundSessionTimeout must be greater than or equal to zero.',
);
}
if (config.backgroundSessionTimeout < 0) {
throw ArgumentError(
'backgroundSessionTimeout must be greater than or equal to zero.',
);
}
}