ContextSession class

Constructors

ContextSession({required int sessionId, required int sessionIndex, required bool? sessionStart, required int eventIndex, required int? previousSessionId, required String firstEventId, required String firstEventTimestamp})

Properties

eventIndex int
final
firstEventId String
final
firstEventTimestamp String
final
hashCode int
The hash code for this object.
no setterinherited
previousSessionId int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId int
final
sessionIndex int
final
sessionStart bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited