SessionState class

Constructors

SessionState({required int sessionId, required int sessionIndex, required int? previousSessionId, required String firstEventId, required String firstEventTimestamp, required int eventIndex, required int lastActivityAt, required int? backgroundedAt})
SessionState.fromJson(Map<String, dynamic> json)
factory

Properties

backgroundedAt int?
final
eventIndex int
final
firstEventId String
final
firstEventTimestamp String
final
hashCode int
The hash code for this object.
no setterinherited
lastActivityAt int
final
previousSessionId int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId int
final
sessionIndex int
final

Methods

copyWith({int? sessionId, int? sessionIndex, int? previousSessionId, bool clearPreviousSessionId = false, String? firstEventId, String? firstEventTimestamp, int? eventIndex, int? lastActivityAt, int? backgroundedAt, bool clearBackgroundedAt = false}) SessionState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited