SessionStateState class

Inheritance

Constructors

SessionStateState(Store store)

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
isReady bool
no setterinherited
ready Future<void>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state Future<SessionState?>
no setterinherited

Methods

addListener(Listener<SessionState?> listener, {bool fireImmediately = true}) → RemoveListener
inherited
dispose() → void
inherited
fromJson(Map<String, dynamic> json) SessionState?
override
init(ErrorHandler errorHandler, bool storageJson) → void
inherited
modifyState(Future modifier(SessionState? state)) Future
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setState(SessionState? value) → void
inherited
toJson(SessionState? t) Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited