SessionPlugin class

Inheritance
Mixed-in types

Constructors

SessionPlugin({int now()?, SessionStateCoordinator? sessionStateCoordinator})

Properties

analytics Analytics?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
now int Function()
final
pAnalytics Analytics?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type PluginType
finalinherited

Methods

clear() → void
override
configure(Analytics analytics) → void
override
execute(RawEvent event) Future<RawEvent?>
override
handleAppStateChange(AppStatus nextAppState) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() Future<void>
override
shutdown() → void
override
toString() String
A string representation of this object.
inherited
update(Map<String, dynamic> settings, ContextUpdateType type) → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited