SessionPluginHelper class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
enrichEvent(SessionState state, int now, {bool updateActivity = true})
→ EnrichedSessionEvent
-
-
ensureFirstEvent(SessionState state, String messageId, String timestamp)
→ SessionState
-
-
isEnabled(Configuration config)
→ bool
-
-
markBackgrounded(SessionState? state, int now)
→ SessionState?
-
-
markForegrounded({required SessionState? state, required int now, int backgroundSessionTimeout = 0})
→ SessionState?
-
-
processEvent({required SessionState? state, required int now, required String messageId, required String timestamp, int foregroundSessionTimeout = 0, int backgroundSessionTimeout = 0, bool isAppInBackground = false})
→ EnrichedSessionEvent
-
-
rotateSession(SessionState? state, int now, String firstEventId, String firstEventTimestamp)
→ SessionState
-
-
shouldRotateOnInactivity(SessionState? state, int now, {int foregroundSessionTimeout = 0})
→ bool
-
-
shouldRotateOnResume(SessionState? state, int now, {int backgroundSessionTimeout = 0})
→ bool
-
-
validateSessionTimeouts(Configuration config)
→ void
-