StateManager class

Constructors

StateManager(Store store, System system, Configuration configuration)

Properties

configuration ConfigurationState
final
context ContextState
final
deepLinkData DeepLinkDataState
final
filters FiltersState
final
hashCode int
The hash code for this object.
no setterinherited
integrations IntegrationsState
final
isReady bool
no setter
ready Future
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionState SessionStateState
final
system SystemState
final
userInfo UserInfoState
final

Methods

disposeAppStateStreamMultiplexer() Future<void>
init(ErrorHandler errorHandler, bool storageJson) → void
listenAppState(void onData(AppStatus)) StreamSubscription<AppStatus>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited